@@ -2,7 +2,7 @@
 """
 @Author: ChenCheng
 @Date: 2022-03-18 10:12:12
-@LastEditTime: 2022-07-25 11:42:53
+@LastEditTime: 2022-07-25 15:21:48
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -157,7 +157,7 @@ class LaunchGoodsListHandler(TopBaseHandler):
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 0))
         goods_id = self.get_param("goods_id")
-        launch_status = int(self.get_param("launch_status", 0))
+        launch_status = int(self.get_param("launch_status", -1))
         invoke_result_data = self.get_launch_goods_list(app_id, act_id, page_size, page_index, self.get_param("access_token"), goods_id, launch_status)
         if invoke_result_data["success"] == False:
             return self.response_json_error(invoke_result_data["error_code"], invoke_result_data["error_message"])
@@ -198,6 +198,8 @@ class LaunchGoodsListHandler(TopBaseHandler):
         #获取商品信息
         goods_list = []
         if len(launch_goods_list) > 0:
+            for launch_goods in launch_goods_list:
+                launch_goods["goods_id"] = int(launch_goods["goods_id"])
             goods_ids = ",".join([str(launch_goods["goods_id"]) for launch_goods in launch_goods_list])
 
             resq = self.get_goods_list_for_goodsids(goods_ids, access_token)
